# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"R": "01_wrapper.ipynb",
         "dict2ri": "02_converter.ipynb",
         "ri2dict": "02_converter.ipynb",
         "tuple2ri": "02_converter.ipynb",
         "none2ri": "02_converter.ipynb",
         "datetime2ri": "02_converter.ipynb",
         "dataframe_non_string_category_wrapper": "02_converter.ipynb",
         "converter": "02_converter.ipynb"}

modules = ["wrapper.py",
           "converter.py"]

doc_url = "https://hgzech.github.io/biur/"

git_url = "https://github.com/hgzech/biur/tree/main/"

def custom_doc_links(name): return None
